@@ -190,7 +190,9 @@ int EventLoop(void)
           sleep(1);
         else {
           /* less than one second remaining:  do delay in msec, then return */
-          Timer((remaining_interval * 1000L) / clock_ticks);  /* can't overflow */
+          if (remaining_interval > 0) {
+            Timer((remaining_interval * 1000L) / clock_ticks);  /* can't overflow */
+          }
           return waitloop? NEXTLOOP : NEXTQUIT;
         }
 #else
@@ -694,7 +696,7 @@ int HandleEvent(XEvent *event, int *donep)
 	if (wasJpegUp) { JPEGDialog(wasJpegUp);  wasJpegUp=0; }
 #endif
 #ifdef HAVE_JP2K
-	if (wasJp2kUp) { JP2KDialog(wasJpegUp);  wasJp2kUp=0; }
+	if (wasJp2kUp) { JP2KDialog(wasJp2kUp);  wasJp2kUp=0; }
 #endif
 #ifdef HAVE_TIFF
 	if (wasTiffUp) { TIFFDialog(wasTiffUp);  wasTiffUp=0; }
